@@ -1,7 +1,8 @@
 """The Fjäråskupan integration."""
 from __future__ import annotations
 
-from collections.abc import Callable
+from collections.abc import AsyncIterator, Callable
+from contextlib import asynccontextmanager
 from dataclasses import dataclass
 from datetime import timedelta
 import logging
@@ -14,11 +15,15 @@ from homeassistant.components.bluetooth import (
     BluetoothScanningMode,
     BluetoothServiceInfoBleak,
     async_address_present,
+    async_ble_device_from_address,
+    async_rediscover_address,
     async_register_callback,
 )
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import Platform
 from homeassistant.core import HomeAssistant, callback
+from homeassistant.exceptions import HomeAssistantError
+from homeassistant.helpers import device_registry as dr
 from homeassistant.helpers.dispatcher import (
     async_dispatcher_connect,
     async_dispatcher_send,
@@ -29,6 +34,11 @@ from homeassistant.helpers.update_coordinator import DataUpdateCoordinator, Upda
 
 from .const import DISPATCH_DETECTION, DOMAIN
 
+
+class UnableToConnect(HomeAssistantError):
+    """Exception to indicate that we can not connect to device."""
+
+
 PLATFORMS = [
     Platform.BINARY_SENSOR,
     Platform.FAN,
@@ -71,13 +81,20 @@ class Coordinator(DataUpdateCoordinator[State]):
     async def _async_update_data(self) -> State:
         """Handle an explicit update request."""
         if self._refresh_was_scheduled:
-            if async_address_present(self.hass, self.device.address):
+            if async_address_present(self.hass, self.device.address, False):
                 return self.device.state
             raise UpdateFailed(
                 "No data received within schedule, and device is no longer present"
             )
 
-        await self.device.update()
+        if (
+            ble_device := async_ble_device_from_address(
+                self.hass, self.device.address, True
+            )
+        ) is None:
+            raise UpdateFailed("No connectable path to device")
+        async with self.device.connect(ble_device) as device:
+            await device.update()
         return self.device.state
 
     def detection_callback(self, service_info: BluetoothServiceInfoBleak) -> None:
@@ -85,6 +102,21 @@ class Coordinator(DataUpdateCoordinator[State]):
         self.device.detection_callback(service_info.device, service_info.advertisement)
         self.async_set_updated_data(self.device.state)
 
+    @asynccontextmanager
+    async def async_connect_and_update(self) -> AsyncIterator[Device]:
+        """Provide an up to date device for use during connections."""
+        if (
+            ble_device := async_ble_device_from_address(
+                self.hass, self.device.address, True
+            )
+        ) is None:
+            raise UnableToConnect("No connectable path to device")
+
+        async with self.device.connect(ble_device) as device:
+            yield device
+
+        self.async_set_updated_data(self.device.state)
+
 
 @dataclass
 class EntryState:
@@ -111,8 +143,9 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
         else:
             _LOGGER.debug("Detected: %s", service_info)
 
-            device = Device(service_info.device)
+            device = Device(service_info.device.address)
             device_info = DeviceInfo(
+                connections={(dr.CONNECTION_BLUETOOTH, service_info.address)},
                 identifiers={(DOMAIN, service_info.address)},
                 manufacturer="Fjäråskupan",
                 name="Fjäråskupan",
@@ -133,6 +166,7 @@ async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
             BluetoothCallbackMatcher(
                 manufacturer_id=20296,
                 manufacturer_data_start=[79, 68, 70, 74, 65, 82],
+                connectable=False,
             ),
             BluetoothScanningMode.ACTIVE,
         )
@@ -175,4 +209,11 @@ async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     if unload_ok:
         hass.data[DOMAIN].pop(entry.entry_id)
 
+        for device_entry in dr.async_entries_for_config_entry(
+            dr.async_get(hass), entry.entry_id
+        ):
+            for conn in device_entry.connections:
+                if conn[0] == dr.CONNECTION_BLUETOOTH:
+                    async_rediscover_address(hass, conn[1])
+
     return unload_ok
