@@ -24,7 +24,6 @@ from homeassistant.core import HomeAssistant, callback
 from homeassistant.data_entry_flow import AbortFlow, FlowResult
 from homeassistant.helpers import device_registry as dr
 
-from .connection import HKDevice
 from .const import DOMAIN, KNOWN_DEVICES
 from .storage import async_get_entity_storage
 from .utils import async_get_controller
@@ -253,17 +252,6 @@ class HomekitControllerFlowHandler(config_entries.ConfigFlow, domain=DOMAIN):
         category = Categories(int(properties.get("ci", 0)))
         paired = not status_flags & 0x01
 
-        # The configuration number increases every time the characteristic map
-        # needs updating. Some devices use a slightly off-spec name so handle
-        # both cases.
-        try:
-            config_num = int(properties["c#"])
-        except KeyError:
-            _LOGGER.warning(
-                "HomeKit device %s: c# not exposed, in violation of spec", hkid
-            )
-            config_num = None
-
         # Set unique-id and error out if it's already configured
         existing_entry = await self.async_set_unique_id(
             normalized_hkid, raise_on_progress=False
@@ -280,17 +268,6 @@ class HomekitControllerFlowHandler(config_entries.ConfigFlow, domain=DOMAIN):
                 self.hass.config_entries.async_update_entry(
                     existing_entry, data={**existing_entry.data, **updated_ip_port}
                 )
-            conn: HKDevice = self.hass.data[KNOWN_DEVICES][hkid]
-            # When we rediscover the device, let aiohomekit know
-            # that the device is available and we should not wait
-            # to retry connecting any longer. reconnect_soon
-            # will do nothing if the device is already connected
-            await conn.pairing.reconnect_soon()
-            if config_num and conn.config_num != config_num:
-                _LOGGER.debug(
-                    "HomeKit info %s: c# incremented, refreshing entities", hkid
-                )
-                conn.async_notify_config_changed(config_num)
             return self.async_abort(reason="already_configured")
 
         _LOGGER.debug("Discovered device %s (%s - %s)", name, model, hkid)
