@@ -6,6 +6,7 @@ import copy
 import logging
 import random
 import string
+from typing import Any
 from urllib.parse import urlparse
 
 import voluptuous as vol
@@ -171,11 +172,11 @@ class KonnectedFlowHandler(config_entries.ConfigFlow, domain=DOMAIN):
     VERSION = 1
 
     # class variable to store/share discovered host information
-    discovered_hosts = {}
+    discovered_hosts: dict[str, dict[str, Any]] = {}
 
     def __init__(self) -> None:
         """Initialize the Konnected flow."""
-        self.data = {}
+        self.data: dict[str, Any] = {}
         self.options = OPTIONS_SCHEMA({CONF_IO: {}})
 
     async def async_gen_config(self, host, port):
@@ -271,6 +272,7 @@ class KonnectedFlowHandler(config_entries.ConfigFlow, domain=DOMAIN):
             _LOGGER.error("Malformed Konnected SSDP info")
         else:
             # extract host/port from ssdp_location
+            assert discovery_info.ssdp_location
             netloc = urlparse(discovery_info.ssdp_location).netloc.split(":")
             self._async_abort_entries_match(
                 {CONF_HOST: netloc[0], CONF_PORT: int(netloc[1])}
@@ -392,10 +394,10 @@ class OptionsFlowHandler(config_entries.OptionsFlow):
         self.current_opt = self.entry.options or self.entry.data[CONF_DEFAULT_OPTIONS]
 
         # as config proceeds we'll build up new options and then replace what's in the config entry
-        self.new_opt = {CONF_IO: {}}
+        self.new_opt: dict[str, dict[str, Any]] = {CONF_IO: {}}
         self.active_cfg = None
-        self.io_cfg = {}
-        self.current_states = []
+        self.io_cfg: dict[str, Any] = {}
+        self.current_states: list[dict[str, Any]] = []
         self.current_state = 1
 
     @callback
