@@ -1,19 +1,20 @@
 """Support for Litter-Robot "Vacuum"."""
 from __future__ import annotations
 
-import logging
 from typing import Any
 
+from pylitterbot import LitterRobot
 from pylitterbot.enums import LitterBoxStatus
-from pylitterbot.robot import VALID_WAIT_TIMES
 import voluptuous as vol
 
 from homeassistant.components.vacuum import (
+    DOMAIN as PLATFORM,
     STATE_CLEANING,
     STATE_DOCKED,
     STATE_ERROR,
     STATE_PAUSED,
     StateVacuumEntity,
+    StateVacuumEntityDescription,
     VacuumEntityFeature,
 )
 from homeassistant.config_entries import ConfigEntry
@@ -23,16 +24,10 @@ from homeassistant.helpers import config_validation as cv, entity_platform
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 from .const import DOMAIN
-from .entity import LitterRobotControlEntity
+from .entity import LitterRobotControlEntity, async_update_unique_id
 from .hub import LitterRobotHub
 
-_LOGGER = logging.getLogger(__name__)
-
-TYPE_LITTER_BOX = "Litter Box"
-
-SERVICE_RESET_WASTE_DRAWER = "reset_waste_drawer"
 SERVICE_SET_SLEEP_MODE = "set_sleep_mode"
-SERVICE_SET_WAIT_TIME = "set_wait_time"
 
 LITTER_BOX_STATUS_STATE_MAP = {
     LitterBoxStatus.CLEAN_CYCLE: STATE_CLEANING,
@@ -46,6 +41,8 @@ LITTER_BOX_STATUS_STATE_MAP = {
     LitterBoxStatus.OFF: STATE_OFF,
 }
 
+LITTER_BOX_ENTITY = StateVacuumEntityDescription("litter_box", name="Litter Box")
+
 
 async def async_setup_entry(
     hass: HomeAssistant,
@@ -55,19 +52,14 @@ async def async_setup_entry(
     """Set up Litter-Robot cleaner using config entry."""
     hub: LitterRobotHub = hass.data[DOMAIN][entry.entry_id]
 
-    async_add_entities(
-        [
-            LitterRobotCleaner(robot=robot, entity_type=TYPE_LITTER_BOX, hub=hub)
-            for robot in hub.account.robots
-        ]
-    )
+    entities = [
+        LitterRobotCleaner(robot=robot, hub=hub, description=LITTER_BOX_ENTITY)
+        for robot in hub.litter_robots()
+    ]
+    async_update_unique_id(hass, PLATFORM, entities)
+    async_add_entities(entities)
 
     platform = entity_platform.async_get_current_platform()
-    platform.async_register_entity_service(
-        SERVICE_RESET_WASTE_DRAWER,
-        {},
-        "async_reset_waste_drawer",
-    )
     platform.async_register_entity_service(
         SERVICE_SET_SLEEP_MODE,
         {
@@ -76,14 +68,9 @@ async def async_setup_entry(
         },
         "async_set_sleep_mode",
     )
-    platform.async_register_entity_service(
-        SERVICE_SET_WAIT_TIME,
-        {vol.Required("minutes"): vol.All(vol.Coerce(int), vol.In(VALID_WAIT_TIMES))},
-        "async_set_wait_time",
-    )
 
 
-class LitterRobotCleaner(LitterRobotControlEntity, StateVacuumEntity):
+class LitterRobotCleaner(LitterRobotControlEntity[LitterRobot], StateVacuumEntity):
     """Litter-Robot "Vacuum" Cleaner."""
 
     _attr_supported_features = (
@@ -118,18 +105,6 @@ class LitterRobotCleaner(LitterRobotControlEntity, StateVacuumEntity):
         """Start a clean cycle."""
         await self.perform_action_and_refresh(self.robot.start_cleaning)
 
-    async def async_reset_waste_drawer(self) -> None:
-        """Reset the waste drawer level."""
-        # The Litter-Robot reset waste drawer service has been replaced by a
-        # dedicated button entity and marked as deprecated
-        _LOGGER.warning(
-            "The 'litterrobot.reset_waste_drawer' service is deprecated and "
-            "replaced by a dedicated reset waste drawer button entity; Please "
-            "use that entity to reset the waste drawer instead"
-        )
-        await self.robot.reset_waste_drawer()
-        self.coordinator.async_set_updated_data(True)
-
     async def async_set_sleep_mode(
         self, enabled: bool, start_time: str | None = None
     ) -> None:
@@ -140,17 +115,6 @@ class LitterRobotCleaner(LitterRobotControlEntity, StateVacuumEntity):
             self.parse_time_at_default_timezone(start_time),
         )
 
-    async def async_set_wait_time(self, minutes: int) -> None:
-        """Set the wait time."""
-        # The Litter-Robot set wait time service has been replaced by a
-        # dedicated select entity and marked as deprecated
-        _LOGGER.warning(
-            "The 'litterrobot.set_wait_time' service is deprecated and "
-            "replaced by a dedicated set wait time select entity; Please "
-            "use that entity to set the wait time instead"
-        )
-        await self.perform_action_and_refresh(self.robot.set_wait_time, minutes)
-
     @property
     def extra_state_attributes(self) -> dict[str, Any]:
         """Return device specific state attributes."""
